@@ -1,13 +1,13 @@
-import shutil
-import sqlite3
-import datetime
-import asyncio
-import queue
-import os
-import json
+from omnitools import args, key_pair_format, join_path, abs_main_dir
 from threadwrapper import *
 from easyrsa import *
-from omnitools import args, key_pair_format, join_path, abs_main_dir
+import datetime
+import sqlite3
+import asyncio
+import shutil
+import queue
+import json
+import os
 
 
 __ALL__ = ["SqlQueue"]
@@ -26,7 +26,7 @@ class SqlQueue:
                 str(now.day).zfill(2),
                 str(now.hour).zfill(2),
                 str(now.minute).zfill(2),
-                "{}.{}.{}".format(a, int(time.time()*1000), b)
+                "{}.{}.{}".format(a, int(time.time()*1000), b[1:])
             )
             os.makedirs(os.path.dirname(c), exist_ok=True)
             return c
@@ -154,7 +154,7 @@ class SqlQueue:
             self.wait_task_to_finish("terminate", "worker_dead")
 
     def __init__(
-            self,
+            self, *,
             server: bool = False, db: str = "",
             timeout_commit: int = 60*1000, auto_backup: bool = False, timeout_backup: int = 60*1000,
             export_functions = None
@@ -239,14 +239,14 @@ class SqlQueue:
             loop = asyncio.new_event_loop()
             asyncio.set_event_loop(loop)
             twa = ThreadWrapper_async(asyncio.Semaphore(1), loop=loop)
-            twa.add(self._sql_async(threading.get_ident(), sql, data, row_factory, _cmd), result, key)
+            twa.add(job=self._sql_async(threading.get_ident(), sql, data, row_factory, _cmd), result=result, key=key)
             twa.wait()
 
         tw = ThreadWrapper(threading.Semaphore(1))
         if exc_type == "async":
-            tw.add(job2)
+            tw.add(job=job2)
         else:
-            tw.add(job1, result, key)
+            tw.add(job=job1, result=result, key=key)
         tw.wait()
         if isinstance(result[key], Exception):
             if isinstance(result[key], sqlite3.OperationalError):
@@ -267,19 +267,19 @@ class SqlQueue:
 
 
 class SqlQueueE(SqlQueue):
-    def __init__(self, host = "127.199.71.10", db_port: int = None, key_pair: key_pair_format = None, **kwargs) -> None:
+    def __init__(self, *, host = "127.199.71.10", db_port: int = None, key_pair: key_pair_format = None, **kwargs) -> None:
         super().__init__(**kwargs)
         port = db_port if db_port else 39292
         from encryptedsocket import SC, SS
         if self.is_server:
             if key_pair is None:
                 key_pair = EasyRSA(bits=1024).gen_key_pair()
-            self.ss = SS(key_pair, self.functions, host, port, True)
+            self.ss = SS(key_pair=key_pair, functions=self.functions, host=host, port=port, silent=True)
             thread = threading.Thread(target=self.ss.start)
             thread.daemon = True
             thread.start()
         else:
-            self.sc = lambda: SC(host, port)
+            self.sc = lambda: SC(host=host, port=port)
 
     def stop(self):
         super().stop()
@@ -289,17 +289,17 @@ class SqlQueueE(SqlQueue):
 
 
 class SqlQueueU(SqlQueue):
-    def __init__(self, host = "127.199.71.10", db_port: int = None, **kwargs) -> None:
+    def __init__(self, *, host = "127.199.71.10", db_port: int = None, **kwargs) -> None:
         super().__init__(**kwargs)
         port = db_port if db_port else 39292
         from unencryptedsocket import SC, SS
         if self.is_server:
-            self.ss = SS(self.functions, host, port, True)
+            self.ss = SS(functions=self.functions, host=host, port=port, silent=True)
             thread = threading.Thread(target=self.ss.start)
             thread.daemon = True
             thread.start()
         else:
-            self.sc = lambda: SC(host, port)
+            self.sc = lambda: SC(host=host, port=port)
 
     def stop(self):
         super().stop()
