@@ -31,7 +31,7 @@ for func in [_sql, _sql_async, sql, sql_async]:
         sqlqueue.commit()
         start = time.time()
         for i in range(j):
-            twa.add(func(i, loop, result, i))
+            twa.add(job=func(i, loop, result, i))
         twa.wait()
         sqlqueue.commit()
         elapsed = time.time()-start
